import java.io.*;
import java.util.*;

/* Judge Solution by Jesus Ramos, MyACM Triangles, Division A
 * To test if a triangle contains a certain point inside it you can use Heron's Area Formula
 * as stated in the problem introduction to subdivide the triangle being tested
 * into 3 regions. The way these regions are subdivided is such that the point being tested
 * as to whether it is contained in the triangle is used as a vertex for 3 seperate triangles
 * by combining that point with 2 of the vertex's of the triangle.
 * If the total area of those 3 regions is equal to the area of the triangle
 * itself, then the point must either be collinear to one of the sides or inside the triangle.
 */

public class Triangles
{
	static Point[] points;
    static double largestArea;
    static String largest;
	
	public static void main(String[] args) throws Exception
	{
		Scanner in = new Scanner(System.in);
		//PrintWriter out = new PrintWriter("triangles.out");
		while (in.hasNextInt())
		{
            largestArea = 0;
            largest = "";
			int p = in.nextInt();
			if (p==0)
				break;
			points = new Point[p];
			for (int j=0; j<p; j++)
				points[j] = new Point(in.next(), in.nextInt(), in.nextInt());
			findSolution();
		}
		//out.close();
	}
	static void findSolution()
	{
		// to find the solution simply attempt every combination of points as long as the points are in increasing order
		// if not you end up checking the same triangles more than once
		int lim = points.length;
		for (int a=0; a<lim; a++)
			for (int b=a+1; b<lim; b++)
				for (int c=b+1; c<lim; c++)
				{
                    boolean validTriangle = true;
                    Point a1 = points[a];
                    Point a2 = points[b];
                    Point a3 = points[c];
                    double area = triArea(a1.x, a1.y, a2.x, a2.y, a3.x, a3.y); // find the area for a triangle to test
                    for (Point p : points)
                    {
						// check if any of the points lie inside this triangle
						boolean pInside = pointInside(p.x, p.y, a1.x, a1.y, a2.x, a2.y, a3.x, a3.y);
						// make sure that the point being tested isnt already part of the triangle
						boolean otherPoint = p!=a1 && p!=a2 && p!=a3;
						if (pInside && otherPoint)
							validTriangle = false;
					}
					// better triangle found than the previous remember it as the best
                    if (validTriangle && area > largestArea)
                    {
                        largestArea = area;
                        largest = a1.name + a2.name + a3.name;
                    }
				}
		System.out.println(largest);
	}
	static boolean pointInside(double x, double y, double x1, double y1, double x2, double y2, double x3, double y3) //x and y are the points being tested
	{
		// subdivide the triangle into 3 smaller triangles and use this to determine if the point is inside
		// if the point is inside the addition of all 3 areas should equals the area of the triangle itself
		// if it is greater the point must lie outside the triangle
		double tot, t1, t2, t3;
		tot = triArea(x1, y1, x2, y2, x3, y3);
		t1 = triArea(x, y, x2, y2, x3, y3);
		t2 = triArea(x, y, x1, y1, x2, y2);
		t3 = triArea(x, y, x1, y1, x3, y3);
		return t1+t2+t3==tot;
	}
	static double triArea(double x1, double y1, double x2, double y2, double x3, double y3) // Heron's Area Formula
	{
		double a,b,c,d;
		a = x1-x3;
		b = y1-y3;
		c = x2-x3;
		d = y2-y3;
		return (0.5 * Math.abs((a*d)-(b*c)));
	} 
}
class Point
{
	public int x, y;
	public String name;
	
	public Point(String n, int xx, int yy)
	{
		name = n;
		x = xx;
		y = yy;
	}
}