//import java.io.*;
import java.util.*;

/* Judge Solution by Jesus Ramos, Jungle Roads, Division A
 * The solution is to simply find the cost of the minimum spanning tree of the villages
 * Consider the villages as disconnected nodes on a graph
 * You simply sort the edges and add them to the tree as long as they do connect nodes or components that
 * are already in the tree, to find the sum you simply add up the weights of all the edges in this tree
 * I use Kruskal's in this example but it can also be solved using Prim's Algorithm
 */

public class JungleRoads
{
	public static void main(String[] args) throws Exception
	{
		Scanner in = new Scanner(System.in);
		//PrintWriter out = new PrintWriter("jungle.out");
		int numVillages;
		TreeSet<Edge> edges; // self sorting set of edges
		while (in.hasNextInt())
		{
			SpanningTree minTree = new SpanningTree();
			edges = new TreeSet<Edge>();
			numVillages = in.nextInt();
			if (numVillages == 0)
				break;
			for (int i=0; i < numVillages - 1; i++)
			{
				String village = in.next();
				int roads = in.nextInt();
				for (int j=0; j<roads; j++)
				{
					String otherVillage = in.next();
					int weight = in.nextInt();
					Edge e = new Edge(village, otherVillage, weight);
					edges.add(e); // add edge to the set
				}
			}
			for (Edge e : edges) // go through all edges until all edge components are in the tree
				minTree.addEdge(e);
			// calculate the cost by adding the weights of all the edges in the tree
			int total = 0;
			for (Edge e : minTree.edgesInTree)
				total += e.weight;
			System.out.println(total);
		}
		//out.close();
	}
}
class Edge implements Comparable<Edge>
{
	public String vertexFrom, vertexTo;
	public int weight;
	
	public Edge(String a, String b, int w)
	{
		vertexFrom = a;
		vertexTo = b;
		weight = w;
	}
	public int compareTo(Edge e)
	{
		// I'm using a TreeSet so I CANNOT return 0 or else that edge is simply removed from the set because it is "identical"
		if (this.weight < e.weight)
			return -1;
		return 1;
	}
}
class SpanningTree
{
	ArrayList<HashSet<String>> vertexes; //store all groups of vertexes
	public TreeSet<Edge> edgesInTree;
	
	public SpanningTree()
	{
		vertexes = new ArrayList<HashSet<String>>();
		edgesInTree = new TreeSet<Edge>();
	}
	public HashSet<String> findVertex(String v) // find the component group for which the vertex belongs to if any
	{
		for (HashSet<String> verts : vertexes)
			if (verts.contains(v))
				return verts;
		return null; // the vertex is not yet present in the tree
	}
	public void addEdge(Edge e)
	{
		String vA = e.vertexFrom;
		String vB = e.vertexTo;
		HashSet<String> componentA = findVertex(vA);
		HashSet<String> componentB = findVertex(vB);
		if (componentA == null) // means A is not in the tree yet
		{
			edgesInTree.add(e); // add edge to the tree
			if (componentB == null) // no connected component to the second vertex
			{
				HashSet<String> newComp = new HashSet<String>(); // add both vertexes to a connected component for B
				newComp.add(vA);
				newComp.add(vB);
				vertexes.add(newComp);
			}
			else // if not just connect A with B
				componentB.add(vA);
		}
		else
		{
			if (componentB == null) // means B is not in the tree
			{
				componentA.add(vB); //connect B into A's component and add the edge to the tree
				edgesInTree.add(e);
			}
			else if (componentA != componentB) // means they are disconnected components but they are in the tree so add both components together
			{
				componentA.addAll(componentB); // connect all of the components to each other
				vertexes.remove(componentB); // no longer disconnected component, remove it from vertex list since we added a new connected component
				edgesInTree.add(e); // add the edge to the tree
			}
		}
		// if none of these happen then edge is already in tree or a better edge connecting them was found
	}
}