// KnightMoves.c - by Kip Irvine

// Solution to the Knight Moves problem (ACM Contest Problems Archive #439)
// Assignment 3, Spring 2010

#define _CRT_SECURE_NO_WARNINGS
#include <stdio.h>
#include <stdlib.h>
#include <ctype.h>

typedef struct MoveStruct {
	int x, y;
	int distance;
} Move;

#define true 1
#define false 0

#define QUEUESIZE 64
Move queue[QUEUESIZE];
int head, tail;

Move goal;			   // this is where we hope to end up

int visited[8][8];   // marks the visited squares

int isValid( Move S )
{
	return S.x >= 0 && S.x < 8
		&& S.y >=0 && S.y < 8;
}

// maps chess coordinates to x, y coordinates.
// for example, "a1" = 7,0;   "h8" = 0,7

void mapCoordinates( char * chess, int * x, int * y )
{
	*x = tolower(chess[0]) - 'a';
	*y = 8 - (chess[1] - '0');
}

// clear the visited array & queue
void initialize()
{
	int x, y;	
	head = tail = 0;
	
	for(x=0; x < 7; x++)
		for(y=0; y < 7; y++)
			visited[x][y] = false;
}

// remove the first Move from the queue
Move serve( )
{
	// if head == tail, the queue is empty
	head = (head + 1) % QUEUESIZE;
	return queue[head];
}

// add a move to the queue
void enqueue( Move S )
{
	tail = (tail + 1) % QUEUESIZE;
	queue[tail] = S;
}


// add X and Y offsets to the current Move. 
// If the goal square is found, return the length
// of the path that was required to reach this move.

int add( Move S, int xofs, int yofs )
{
	S.x += xofs;
	S.y += yofs;
	
	if( S.x == goal.x && S.y == goal.y )
		return true;
		
	if( isValid(S)&& !visited[S.x][S.y] ) {
		visited[S.x][S.y] = true;
		enqueue( S );
	}
	return false;
}

// Search for the shortest number of moves between Squares first 
// and last. Visit each Move connected to S. Then, visit all Moves
// connected to those Moves.

int search( char * first, char * last )
{
	Move S;
	int i;
	int xmov[] = {1,-1,2,-2,-2,2,-1,1};
	int ymov[] = {-2,-2,-1,-1,1,1,2,2};
	S.distance = 0;	
	mapCoordinates( first, &S.x, &S.y );

	while( true )
	{
		// see if we've reached the goal
		if( S.x == goal.x && S.y == goal.y )
			return S.distance;

		S.distance++;
		
		// add all the possible next moves to the queue
		for(i=0; i < 8; i++) {
			if( add(S, xmov[i], ymov[i] ))
				return S.distance;
		}
		
		S = serve();    // get next move from queue
	}  // while
}


void main()
{
	char first[3];
	char last[3];
	int numMoves;
	
	while( scanf("%s %s", first, last ) == 2 )
	{
		initialize();
		mapCoordinates( last, &goal.x, &goal.y );
		numMoves = search( first, last );
	
		printf("To get from %s to %s takes %d knight moves.\n", first, last, numMoves );
	}

}