import java.io.*;
import java.util.*;

/* Judge solution for TwinPrimes by Jesus Ramos, Division B
 * All twin primes are generated through the simple brute force method
 * and placed into a stack so that it is easier to retrieve in
 * reverse order as is stated in the problem introduction
 */

public class TwinPrimes
{
	static Stack<Integer> primes = new Stack<Integer>();
	
	public static void main(String[] args) throws Exception
	{
		//PrintWriter out = new PrintWriter("primes.out");
		findPrimes();
		printPrimes();
	}
	static void printPrimes()
	{
		for (int i=0; i<15; i++)
		{
			int p1 = primes.pop();
			int p2 = primes.pop();
			System.out.println("(" + p1 + "," + p2 + ")");
		}
		//out.close();
	}
	
	static void findPrimes()
	{
		/* Now there are 2 methods to solving this problem but considering this is
		 * for the lower division I will go with the most obvious solution
		 * rather than using the sieve of erastosthenes
		 * instead I will just find the next prime after the current one I have
         * and if that prime is simply lastPrime + 2 then it is a twin prime
         * if not replace the last prime you found with the current one
         * and repeat this process until you have found all twinprime pairs
         */

		int numTwins = 0;
		int lastPrime = 3;
		while (numTwins < 15)
		{
			int next = lastPrime + 2;
			while (!isPrime(next))
				next += 2;
			if (next - lastPrime == 2)
			{
				primes.push(next);
				primes.push(lastPrime);
				numTwins++;
			}
			lastPrime = next;
		}
	}
	static boolean isPrime(int n)
	{
		//if the number is even it can't obviously be prime
		if (n % 2 == 0)
			return false;
		//if not then try dividing by every odd number up to the sqrt(n) because going any higher is just rechecking the same factors
		for (int i = 3; i <= Math.sqrt(n); i+=2)
			if (n % i == 0)
				return false;
		return true;
	}
}
